@@ -9,7 +9,7 @@ use warnings;
 
 use experimental qw( signatures postderef );
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 use Ref::Util;
 use List::Util;
@@ -113,11 +113,9 @@ sub new_from_attrs ( $class, $in_ipar = {}, $in_gpar = {} ) {
                   "value for 'methods' parameter key '$name' must be a code reference"
             ) unless Ref::Util::is_coderef( $code );
 
-            my $cap_name = ucfirst( $name );
-
             # create role for the method
             my $role
-              = eval { Iterator::Flex::Method::Maker( $cap_name, name => $name ) };
+              = eval { Iterator::Flex::Method::Maker( $name, name => $name ) };
 
             if ( $@ ne '' ) {
                 my $error = $@;
@@ -417,7 +415,7 @@ Iterator::Flex::Base - Iterator object
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 METHODS
 
